<?php

/**
 * @file
 * This module displays customizable index pages for each content type, with
 * alphabetical, taxonomy, and user filters.
 */

/**
 * Implements hook_form().
 */
function indexpage_admin_settings() {
  $x = drupal_add_css(drupal_get_path('module', 'indexpage') . '/indexpage.css', array('preprocess' => FALSE));
//  drupal_set_message('<pre>'.print_r($x,true).'</pre>');
  $noyes = array(t('No'), t('Yes'));
  $form['#attached']['css'] = array(drupal_get_path('module', 'indexpage') . '/indepage.css');

  $form['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    );

  $form['general']['indexpage_description'] = array(
    '#type' => 'textarea',
    '#title' => t('Description text for main index page'),
    '#default_value' => variable_get('indexpage_description', ''),
    '#rows' => 1,
    );

  $form['general']['indexpage_maxresults'] = array(
    '#type' => 'textfield',
    '#title' => t('Max number of results per page'),
    '#default_value' => variable_get('indexpage_maxresults', 10),
    '#size' => 2,
    '#maxlength' => 2,
    '#description' => t('This option determines how many items will show on the results page before a pager is added. It also makes term list fieldsets collapse when there are more that this many terms in the list.'),
    );

  $form['general']['indexpage_show_users'] = array(
    '#type' => 'radios',
    '#options' => $noyes,
    '#title' => t('Show users who have submitted this content'),
    '#default_value' => (int) variable_get('indexpage_show_users', FALSE),
    '#description' => t('If this option is selected, an additional section with user names will be shown.'),
    '#attributes' => array('class' => array('container-inline')),
    );

  $form['general']['indexpage_suppress_unused'] = array(
    '#type' => 'radios',
    '#options' => $noyes,
    '#title' => t('Suppress unused taxonomy terms'),
    '#default_value' => (int) variable_get('indexpage_suppress_unused', FALSE),
    '#attributes' => array('class' => array('container-inline')),
    '#description' => t('If this option is selected, terms with no associated nodes will not be shown.')
      . ' '
      . t('Note that taxonomy terms referenced by entity_reference may not be counted (it is an option) in the taxonomy_index table.')
      . ' '
      . t('Also Hierarchical Select may, optionally, count parent terms; otherwise the list may not show any hierarchy.'),
    );

  $form['general']['indexpage_show_count'] = array(
    '#type' => 'radios',
    '#options' => $noyes,
    '#title' => t('Show counts'),
    '#default_value' => (int) variable_get('indexpage_show_count', TRUE),
    '#description' => t('Shows a count of how many nodes there are and how many are used by each term.'),
    '#attributes' => array('class' => array('container-inline')),
    );

  $form['general']['indexpage_show_untagged'] = array(
    '#type' => 'radios',
    '#options' => $noyes,
    '#title' => t('Show untagged'),
    '#default_value' => (int) variable_get('indexpage_show_untagged', TRUE),
    '#description' => t('Shows a count of how many nodes that have no taxonomy term associated.'),
    '#attributes' => array('class' => array('container-inline')),
    );

  $form['general']['indexpage_show_description'] = array(
    '#type' => 'radios',
    '#options' => $noyes,
    '#title' => t('Show term description'),
    '#default_value' => (int) variable_get('indexpage_show_description', FALSE),
    '#description' => t('Shows the description for the term in the term list.'),
    '#attributes' => array('class' => array('container-inline')),
    );

  $form['general']['indexpage_list_format'] = array(
    '#type' => 'radios',
    '#options' => array('list' => t('List'), 'table' => t('Table')),
    '#title' => t('Show terms list as'),
    '#default_value' => variable_get('indexpage_list_format', 'list'),
    '#description' => t('This determines how the list of terms will appear.'),
    '#attributes' => array('class' => array('container-inline')),
    );

  $date_types = array();
  foreach (system_get_date_types() as $name => $info) {
    $date_types[$name] = $info['title'] . ' <small>(' . format_date(REQUEST_TIME, $name) . ')</small>';
  }
  $form['general']['indexpage_date_format'] = array(
    '#type' => 'radios',
    '#options' => $date_types,
    '#title' => t('Show dates as'),
    '#default_value' => variable_get('indexpage_date_format', 'short'),
    '#description' => t('This determines how the dates will appear.'),
//    '#attributes' => array('class' => array('container-inline')),
    );

  $field_list = array(
    'uid' => t('Author'),
    'editors' => t('Editors'),
    'terms' => t('Terms'),
    'type' => t('Content type'),
    'created' => t('Created date/time'),
    'changed' => t('Updated date/time'),
    'status' => t('Published'),
    'promote' => t('Promoted'),
    'sticky' => t('Sticky'),
    'language' => t('Language'),
    );

  $form['general']['indexpage_fields'] = array(
    '#type' => 'checkboxes',
    '#options' => $field_list,
    '#title' => t('Include extra fields on the result page'),
    '#default_value' => variable_get('indexpage_fields', array()),
    '#description' => t('Any selected fields will be included in the results list. The title will always be shown.'),
    '#prefix' => '<div class="indexpage-checkboxes">',
    '#suffix' => '</div>',
    );

  $form['general']['indexpage_default_sort'] = array(
    '#type' => 'select',
    '#options' => array('title' => t('Title')) + $field_list,
    '#title' => t('Default sort order on content listings'),
    '#default_value' => variable_get('indexpage_default_sort', 'title'),
    '#description' => t('This is the order the content lists will be sorted by if no other fields are clicked.'),
    );

  // Not super-happy with this, but this is the easiest way to handle
  // language differences for now.
  $form['general']['indexpage_alphabar'] = array(
    '#type' => 'textfield',
    '#title' => t('Alphabetical Index'),
    '#default_value' => variable_get('indexpage_alphabar', range('A', 'Z')),
    '#description' => t('If any of the content types below request an alphabetical index, enter the proper alphabet for your language here, letters separated by space.'),
    );

  // Do a fieldset for each content type.
  $type_list = node_type_get_types();
  $taxonomy_exists = module_exists('taxonomy');

  foreach ($type_list as $type => $node_type) {
    $name = $node_type->name;
    $set = $type;
    $form[$set] = array(
      '#type' => 'fieldset',
      '#title' => t('Index page settings for @s', array('@s' => $name)),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      );

    $var_prefix = 'indexpage_' . $type;

    $form[$set][$var_prefix . '_name'] = array(
      '#type' => 'textfield',
      '#title' => t('Name to show for this content type'),
      '#default_value' => variable_get($var_prefix . '_name', $name),
      '#size' => 20,
      '#maxlength' => 50,
      );

    $form[$set][$var_prefix . '_enable'] = array(
      '#type' => 'radios',
      '#options' => $noyes,
      '#attributes' => array('class' => array('container-inline')),
      '#title' => t('Enable index page for this content type'),
      '#default_value' => variable_get($var_prefix . '_enable', 1),
      );

    $form[$set][$var_prefix . '_alphaindex'] = array(
      '#type' => 'radios',
      '#options' => $noyes,
      '#attributes' => array('class' => array('container-inline')),
      '#title' => t('Show alphabetical index bar for this content type'),
      '#default_value' => variable_get($var_prefix . '_alphaindex', 1),
      );

    if ($taxonomy_exists) {
      $form[$set][$var_prefix . '_vocfilter'] = array(
        '#type' => 'radios',
        '#options' => $noyes,
        '#attributes' => array('class' => array('container-inline')),
        '#title' => t('Show vocabulary sections for this content type'),
        '#default_value' => variable_get($var_prefix . '_vocfilter', 1),
        );
    }
    else {
      $form[$set][$var_prefix . '_vocfilter'] = array(
        '#type' => 'value',
        '#value' => FALSE,
        );
    }

    $form[$set][$var_prefix . '_page_text'] = array(
      '#type' => 'textarea',
      '#title' => t('Descriptive text to show at the top of the page.'),
      '#rows' => 3,
      '#default_value' => variable_get($var_prefix . '_page_text', $node_type->description),
      );
  }

  $form['#submit'] = array('indexpage_settings_submit');

  return system_settings_form($form);
}

function indexpage_settings_submit($form, &$form_state) {
//  dpm($form_state{'values'}, __FUNCTION__);
  menu_rebuild();
}
